summaryrefslogtreecommitdiff
path: root/misc
diff options
context:
space:
mode:
authorRasmus Andersson <rasmus@notion.se>2017-09-19 01:58:34 +0300
committerRasmus Andersson <rasmus@notion.se>2017-09-19 01:58:34 +0300
commit4fdb4c927e5cfd5bed84e2355bc890337ec34aa5 (patch)
tree7d856f7c45ac13acf53b89e3a466564665b2059c /misc
parenta213c92c252d314cdf567073e726fa34013f9767 (diff)
downloadinter-4fdb4c927e5cfd5bed84e2355bc890337ec34aa5.tar.xz
Rename family from "Interface" to "Inter UI"
Diffstat (limited to 'misc')
-rw-r--r--misc/doc/install-mac.txt10
-rw-r--r--misc/doc/install-win.txt10
-rwxr-xr-xmisc/fixup-features.py2
-rw-r--r--misc/restore-diacritics-kerning.py2
-rwxr-xr-xmisc/ufocompile8
-rwxr-xr-xmisc/versionize-css.py4
6 files changed, 18 insertions, 18 deletions
diff --git a/misc/doc/install-mac.txt b/misc/doc/install-mac.txt
index b3aae815e..1fbb64c67 100644
--- a/misc/doc/install-mac.txt
+++ b/misc/doc/install-mac.txt
@@ -1,7 +1,7 @@
Installing on macOS:
-1. Open the "Interface (OTF)" folder
+1. Open the "Inter UI (OTF)" folder
2. Select all font files
3. Right-click (or ctrl-click) the selected files
and choose "Open with..." → "Font Book"
@@ -13,12 +13,12 @@ cancel the installation and instead try the instructions below:
Installing on macOS, manually:
-1. Copy the "Interface (OTF)" folder
+1. Copy the "Inter UI (OTF)" folder
2. Press cmd-shift-G in Finder
3. Enter "~/Library/Fonts" into the dialog that shows up and press RETURN.
-4. Paste the "Interface (OTF)" folder.
+4. Paste the "Inter UI (OTF)" folder.
-If you have a previous installation of Interface, you should make sure to
+If you have a previous installation of Inter UI, you should make sure to
remove those fonts files before installing new ones.
-See https://github.com/rsms/interface for more information
+See https://github.com/rsms/inter for more information
diff --git a/misc/doc/install-win.txt b/misc/doc/install-win.txt
index ed9dbf8b7..ea86be137 100644
--- a/misc/doc/install-win.txt
+++ b/misc/doc/install-win.txt
@@ -1,7 +1,7 @@
Installing on Windows 10:
-1. Open the "Interface (hinted TTF)" folder
+1. Open the "Inter UI (hinted TTF)" folder
2. Select all font files
3. Right-click the selected files and choose "Install"
@@ -9,11 +9,11 @@ Installing on Windows 10:
Installing on Windows 10, manually:
1. Double-click the downloaded zip file
-2. Copy the "Interface (hinted TTF)" folder
+2. Copy the "Inter UI (hinted TTF)" folder
3. Press Win-Q on your keyboard, then type "fonts" and hit ENTER
-4. Paste the "Interface (hinted TTF)" folder.
+4. Paste the "Inter UI (hinted TTF)" folder.
-If you have a previous installation of Interface, you should make sure
+If you have a previous installation of Inter UI, you should make sure
to remove those fonts files before installing new ones.
-See https://github.com/rsms/interface for more information
+See https://github.com/rsms/inter for more information
diff --git a/misc/fixup-features.py b/misc/fixup-features.py
index 1c2c0d087..e9597f7ae 100755
--- a/misc/fixup-features.py
+++ b/misc/fixup-features.py
@@ -314,7 +314,7 @@ def main():
# FeaParser(featuresFilename + '2', allNames).parse()
- # font = TTFont('build/dist-unhinted/Interface-Regular.otf')
+ # font = TTFont('build/dist-unhinted/Inter-UI-Regular.otf')
# FeaBuilder(font, featuresFilename + '2').build()
diff --git a/misc/restore-diacritics-kerning.py b/misc/restore-diacritics-kerning.py
index d0fe3100f..6fd8c1601 100644
--- a/misc/restore-diacritics-kerning.py
+++ b/misc/restore-diacritics-kerning.py
@@ -24,7 +24,7 @@ from fontTools import ttLib
from robofab.objects.objectsRF import OpenFont
-srcFontPaths = ['src/Interface-Regular.ufo', 'src/Interface-Bold.ufo']
+srcFontPaths = ['src/Inter-UI-Regular.ufo', 'src/Inter-UI-Bold.ufo']
def getTTGlyphList(font): # -> { 'Omega': [2126, ...], ... }
diff --git a/misc/ufocompile b/misc/ufocompile
index 3f4304205..c09f24c92 100755
--- a/misc/ufocompile
+++ b/misc/ufocompile
@@ -13,7 +13,7 @@ from fontbuild.mix import Master
from fontbuild.mix import Mix
-FAMILYNAME = "Interface"
+FAMILYNAME = "Inter UI"
BASEDIR = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir))
def extractSpecializedGlyphs(masterFont):
@@ -90,7 +90,7 @@ def main():
buildTag = readVersionControlTag(BASEDIR)
# Since we reference a shared feature file, copy it to build dir so includes works
- ufoTmpDir = os.path.join(args.out, 'InterfaceUFO')
+ ufoTmpDir = os.path.join(args.out, 'InterUIUFO')
try:
os.makedirs(ufoTmpDir)
except:
@@ -101,7 +101,7 @@ def main():
# Load masters
print('loading master: Regular')
- rg = Master("%s/src/Interface-Regular.ufo" % BASEDIR)
+ rg = Master("%s/src/Inter-UI-Regular.ufo" % BASEDIR)
bl = None
if ALL \
@@ -109,7 +109,7 @@ def main():
or 'bold' in styles or 'bolditalic' in styles \
or 'medium' in styles or 'mediumitalic' in styles:
print('loading master: Black')
- bl = Master("%s/src/Interface-Black.ufo" % BASEDIR)
+ bl = Master("%s/src/Inter-UI-Black.ufo" % BASEDIR)
glyphSpecializations = extractSpecializedGlyphs(rg)
diff --git a/misc/versionize-css.py b/misc/versionize-css.py
index 0033bdb43..0b317462f 100755
--- a/misc/versionize-css.py
+++ b/misc/versionize-css.py
@@ -1,7 +1,7 @@
#!/usr/bin/env python
# encoding: utf8
#
# Updates the "?v=x" in docs/interface.css
#
from __future__ import print_function
import os, sys, re
@@ -18,7 +18,7 @@ def main():
regex = re.compile(r'(url\("[^"]+?v=)([^"]+)("\))')
- cssFileName = os.path.join(rootDir, 'docs', 'interface.css')
+ cssFileName = os.path.join(rootDir, 'docs', 'inter-ui.css')
s = ''
with open(cssFileName, 'r') as f:
@@ -1,7 +1,7 @@
# encoding: utf8
#
-# Updates the "?v=x" in docs/interface.css
+# Updates the "?v=x" in docs/inter-ui.css
#
from __future__ import print_function